pub struct Extent { /* private fields */ }Expand description
Represents a logical extent and its optional physical device starting offset.
Both logical_range boundaries and device_offset must always be a multiple of
BLOCK_SIZE (4096 bytes). The physical device range length is identical to logical_range.
Implementations
Sourceimpl Extent
impl Extent
Sourcepub fn logical_range(&self) -> Range<u64>
pub fn logical_range(&self) -> Range<u64>
Returns the logical range of this extent.
Sourcepub fn device_offset(&self) -> Option<u64>
pub fn device_offset(&self) -> Option<u64>
Returns the optional physical device offset of this extent. If None, this extent is sparse.
Sourcepub fn is_sparse(&self) -> bool
pub fn is_sparse(&self) -> bool
Returns true if this extent is sparse (unbacked by physical storage).