read_blob_metadata

Function read_blob_metadata 

pub fn read_blob_metadata(
    service: &(impl BlockService + ?Sized),
    metadata_extents: &Extents,
    stored_data_size: u64,
    callback: impl FnOnce(DecodedBlobMetadata) + Send + 'static,
)
Reads blob metadata asynchronously from metadata_extents using service. Once the metadata is retrieved, deserialized, and parsed, callback is invoked with DecodedBlobMetadata.

On failure or if the operation is aborted, callback is dropped without being invoked.