pub struct File { /* private fields */ }Expand description
A mapped file containing extents and an optional transformation (compression or encryption).
Implementations
Sourceimpl File
impl File
pub fn new( extents: Extents, uncompressed_size: u64, transform: Transform, ) -> Self
Sourcepub fn extents(&self) -> &Extents
pub fn extents(&self) -> &Extents
Returns the extents mapping logical offsets to device offsets.
Sourcepub fn uncompressed_size(&self) -> u64
pub fn uncompressed_size(&self) -> u64
Returns the uncompressed size of the file in bytes.
Sourcepub fn transform(&self) -> &Transform
pub fn transform(&self) -> &Transform
Returns the transform applied to the file if compressed or encrypted.
Sourcepub fn compression_info(&self) -> Option<&CompressionInfo>
pub fn compression_info(&self) -> Option<&CompressionInfo>
Returns decompression metadata if the file is compressed.
Sourcepub fn read_range(
self: &Arc<Self>,
service: &(impl BlockService + ?Sized),
page_request: impl PageRequest,
)
pub fn read_range( self: &Arc<Self>, service: &(impl BlockService + ?Sized), page_request: impl PageRequest, )
Streams and decodes the uncompressed range requested by page_request, applying readahead.