pub struct PagerThread<S: ?Sized, D: DeliveryHandler> { /* private fields */ }Expand description
An RAII guard for the background pager thread spawned by Files::spawn_pager_thread.
The thread services page requests for as long as this guard is kept alive, and stops when this guard is dropped.