pub struct PagerThread { /* private fields */ }Expand description
A handle to a spawned background thread running run_pager_loop.
Dropping this handle sends a shutdown packet to the port and cleanly joins the thread.
Implementations
Sourceimpl PagerThread
impl PagerThread