pub enum DeliveryCommand {
Data {
key: u64,
target_offset: u64,
length: u32,
offset: u32,
},
RegisterBlob {
key: u64,
offset: u32,
length: u32,
},
}Variants
Data
Informs the verifier that data has been read and decompressed into the delivery queue VMO, ready for verification.
Fields
RegisterBlob
Informs the verifier that the blob’s Merkle tree metadata has been transferred to the queue.