pub enum MappingCommand {
Mappings {
key: u64,
offset: u32,
metadata_count: u32,
blob_count: u32,
},
CloseBlob {
key: u64,
},
}Variants
Mappings
Informs the driver of the extent mappings for a blob.
The VMO payload contains blob_count data extent mappings followed by metadata_count
Merkle extent mappings.
Fields
CloseBlob
Informs the driver that the blob session is closed and mappings can be discarded.