pub struct Extent {
pub logical_range: Range<u64>,
pub device_offset: Option<u64>,
}Expand description
Represents a logical extent and its optional physical device starting offset.
Both logical_range boundaries and device_offset must always be a multiple of
BLOCK_SIZE (4096 bytes). The physical device range length is identical to logical_range.
Fields
logical_range: Range<u64>device_offset: Option<u64>Implementations